@@ -1,5 +1,5 @@
 """Core wxviews package"""
 
 from .node import Sizerable
-from .pipes import setup_instance_node_setter, instance_node_setter, apply_attributes, add_to_sizer
+from .pipes import apply_attributes, add_to_sizer
 from .rendering import WxRenderingContext, get_attr_args, get_init_value
