@@ -1,6 +1,6 @@
 """Widgets"""
 
-from .binding import EventBinding, add_events_rules, bind_check_and_expression, \
+from .binding import EventBinding, use_events_binding, bind_check_and_expression, \
     bind_text_and_expression, check_control_and_property
 from .rendering import WxNode, get_app_pipeline, get_frame_pipeline, get_wx_pipeline, get_root
 from .setters import bind
